@@ -1,4 +1,5 @@
-'''
+'''A powerfull encrypter and decrypter tool.
+
 Num6 is a powerfull Encrypter and Decrypter tool for developers or hackers. Depends on user prospective.
 
 This tool has been developed for educational and research based use only. We will not responsible for any type of miss use.
@@ -7,6 +8,16 @@ Stay with open source, keep contributing in open source.
 
 Thank you.
 Developer Md. Almas Ali
+Email: almaspr3@gmail.com
 '''
 
-__version__ = 0.1
+from .packages import *
+from sys import argv
+
+__version__ = 0.3
+
+try:
+    if argv[1] == '--version':
+        print(f'version {__version__}')
+except:
+    pass
